package com.datacloudsec.scan.service.impl;

import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.common.Constant;
import com.datacloudsec.scan.dao.KeywordTempMapper;
import com.datacloudsec.scan.entity.User;
import com.datacloudsec.scan.service.IKeywordTemp;
import com.datacloudsec.utils.DataRule;
import com.datacloudsec.utils.EncodingDetect;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.JsonUtil;
import com.datacloudsec.utils.ObjectUtil;
import java.io.File;
import java.io.FileInputStream;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;
import javax.servlet.http.HttpSession;
import org.apache.commons.io.FileUtils;
import org.apache.commons.io.IOUtils;
import org.apache.commons.lang.StringUtils;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/KeywordTempService.class */
public class KeywordTempService implements IKeywordTemp {
    private KeywordTempMapper kwdTmpMapper = (KeywordTempMapper) InstanceUtil.newDaoInstance(KeywordTempMapper.class);

    public int searchCount(HttpSession session, String name, String keyword) throws Exception {
        return this.kwdTmpMapper.searchCount(name, keyword, DataRule.getRuleWhere(session, "t_keyword_template"));
    }

    public List<Map<String, Object>> search(HttpSession session, String name, String keyword, Integer offset, Integer limit) throws Exception {
        return this.kwdTmpMapper.search(name, keyword, offset, limit, DataRule.getRuleWhere(session, "t_keyword_template"));
    }

    public void delete(HttpSession session, Integer id, Integer version) throws Exception {
        Integer count = this.kwdTmpMapper.getCountTaskByKid(id);
        if (count != null && count.intValue() > 0) {
            throw new UEException("此关键字模板已被任务引用，请在任务管理中移除引用关系！");
        }
        Map<String, Object> kwdemp = this.kwdTmpMapper.getTemplateById(id);
        String path = ObjectUtil.getString(kwdemp.get("path"), "");
        if (StringUtils.isNotBlank(path)) {
            File f = new File(Constant.KEYWORDS_DIC, path);
            f.delete();
        }
        Integer vcount = Integer.valueOf(this.kwdTmpMapper.delete(id, version, DataRule.getRuleWhere(session, "t_keyword_template")));
        if (vcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
    }

    public void insert(HttpSession session, String name, String content) throws Exception {
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        Integer count = this.kwdTmpMapper.getCountByName(name, (Integer) null, uid);
        if (count != null && count.intValue() > 0) {
            throw new UEException("模板名称已存在！");
        }
        String[] lines = content.split("\\|");
        StringBuilder sb = new StringBuilder();
        for (String line : lines) {
            if (!"".equals(line)) {
                if (line.length() > 100) {
                    throw new UEException("关键字格式错误，单个关键字长度不能超过100个字符！");
                }
                sb.append(line).append("|");
            }
        }
        String content2 = sb.toString().substring(0, sb.length() - 1);
        if (content2.length() > 500) {
            String fname = "user/" + System.nanoTime() + ".txt";
            File f = new File(Constant.KEYWORDS_DIC, fname);
            try {
                File dir = f.getParentFile();
                if (!dir.exists()) {
                    dir.mkdirs();
                }
                FileUtils.writeStringToFile(f, content2, "UTF-8");
                this.kwdTmpMapper.insert(name, content2.substring(0, 500), fname, uid);
                return;
            } catch (Exception e) {
                f.delete();
                throw e;
            }
        }
        this.kwdTmpMapper.insert(name, content2, "", uid);
    }

    public void update(HttpSession session, Integer id, String name, String content, Integer version) throws Exception {
        Integer count = this.kwdTmpMapper.getCountByName(name, id, ((User) session.getAttribute("userInfo")).getId());
        if (count != null && count.intValue() > 0) {
            throw new UEException("模板名称已存在");
        }
        String[] lines = content.split("\\|");
        StringBuilder sb = new StringBuilder();
        for (String line : lines) {
            if (!"".equals(line)) {
                if (line.length() > 100) {
                    throw new UEException("关键字格式错误，单个关键字长度不能超过100个字符！");
                }
                sb.append(line).append("|");
            }
        }
        String content2 = sb.toString().substring(0, sb.length() - 1);
        Map<String, Object> kwdmap = this.kwdTmpMapper.getTemplateById(id);
        String path = ObjectUtil.getString(kwdmap.get("path"), "user/" + System.nanoTime() + ".txt");
        File f = new File(Constant.KEYWORDS_DIC, path);
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        if (content2.length() > 500) {
            if (path == null) {
                path = "user/" + System.nanoTime();
            }
            Integer vcount = Integer.valueOf(this.kwdTmpMapper.update(id, name, content2.substring(0, 500), path, version, DataRule.getRuleWhere(session, "t_keyword_template"), uid));
            if (vcount.intValue() == 0) {
                throw new UEException("数据已被修改或删除，请刷新页面或返回");
            }
            File dir = f.getParentFile();
            if (!dir.exists()) {
                dir.mkdirs();
            }
            FileUtils.writeStringToFile(f, content2, "UTF-8");
            return;
        }
        Integer vcount2 = Integer.valueOf(this.kwdTmpMapper.update(id, name, content2, "", version, DataRule.getRuleWhere(session, "t_keyword_template"), uid));
        if (vcount2.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
        if (f.exists()) {
            f.delete();
        }
    }

    public Map<String, Object> getTemplateById(Integer id) throws Exception {
        return this.kwdTmpMapper.getTemplateById(id);
    }

    public File keywordExp(Integer id) throws Exception {
        Map<String, Object> result = this.kwdTmpMapper.getTemplateById(id);
        String path = ObjectUtil.getString(result.get("path"), "");
        String content = ObjectUtil.getString(result.get("content"), "");
        if (!"".equals(path)) {
            content = FileUtils.readFileToString(new File(Constant.KEYWORDS_DIC, path), "UTF-8");
        }
        File f = new File(Constant.TEMP_DIR, String.valueOf(System.nanoTime()) + ".txt");
        FileUtils.writeStringToFile(f, content, "UTF-8");
        return f;
    }

    public String keywordImp(HttpSession session, String nameOnly, String realName) throws Exception {
        File f = new File(Constant.TEMP_DIR, nameOnly);
        if (f.exists() && f.length() == 0) {
            throw new UEException("请勿上传空文件！");
        }
        FileInputStream fis = null;
        String result = "";
        Map<String, Object> alreadyMap = null;
        try {
            try {
                fis = new FileInputStream(f);
                String name = realName.substring(0, realName.lastIndexOf("."));
                String readFileStr = FileUtils.readFileToString(f, EncodingDetect.getJavaEncode(f));
                String[] lines = readFileStr.split("\\|");
                StringBuilder sb = new StringBuilder();
                for (String line : lines) {
                    if (!"".equals(line) && line.length() <= 100) {
                        sb.append(line).append("|");
                    }
                }
                if (StringUtils.isBlank(sb.toString())) {
                    throw new UEException("导入关键字格式错误！");
                }
                String keyword = sb.toString().substring(0, sb.length() - 1);
                Map<String, Object> idMap = this.kwdTmpMapper.getIdByName(name, DataRule.getRuleWhere(session, "t_keyword_template"));
                if (StringUtils.isNotBlank(name) && StringUtils.isNotBlank(keyword)) {
                    if (name.equals("系统默认")) {
                        throw new UEException("文件名称不能为【系统默认】");
                    }
                    if (idMap == null) {
                        Integer uid = ((User) session.getAttribute("userInfo")).getId();
                        if (keyword.length() > 500) {
                            String fname = "user/" + name + ".txt";
                            File keyfile = new File(Constant.KEYWORDS_DIC, fname);
                            try {
                                if (!keyfile.exists()) {
                                    keyfile.createNewFile();
                                }
                                FileUtils.writeStringToFile(keyfile, keyword, "UTF-8");
                                this.kwdTmpMapper.insert(name, keyword.substring(0, 500), fname, uid);
                            } catch (Exception e) {
                                f.delete();
                                throw e;
                            }
                        } else {
                            this.kwdTmpMapper.insert(name, keyword, "", uid);
                        }
                    } else {
                        alreadyMap = new HashMap<>();
                        alreadyMap.put("id", idMap.get("id"));
                        alreadyMap.put("version", idMap.get("version"));
                        alreadyMap.put("name", name);
                        alreadyMap.put("keyword", keyword);
                    }
                }
                if (alreadyMap != null && alreadyMap.size() > 0) {
                    result = UUID.randomUUID().toString();
                    session.setAttribute(result, JsonUtil.MAPPER_ESCAPE_HTML.writeValueAsString(alreadyMap));
                }
                return result;
            } finally {
                IOUtils.closeQuietly(fis);
                if (f != null && f.exists()) {
                    f.delete();
                }
            }
        } catch (Exception e2) {
            throw e2;
        }
    }

    public List<Map<String, Object>> getKeyName() throws Exception {
        return this.kwdTmpMapper.getKeyName();
    }
}
